@@ -36,7 +36,7 @@ use base qw(
     Clownfish::CFC::Perl::Build::Charmonic
 );
 
-our $VERSION = '0.006000003';
+our $VERSION = '0.006000004';
 $VERSION = eval $VERSION;
 
 use File::Spec::Functions qw( catdir catfile updir rel2abs );
@@ -145,6 +145,19 @@ sub ACTION_code {
     $self->SUPER::ACTION_code;
 
     $self->cf_copy_include_file( 'XSBind.h' );
+
+    # Check whether 'use Clownfish::Test' succeeds. If this fails, it is
+    # probably caused by a failure to find symbols from Clownfish.so,
+    # indicating a build problem. In this case, make the build fail, so
+    # we get the full build log on CPAN Testers. Also print contents of
+    # the generated Makefile.
+    my $error = system("$^X -Mblib -MClownfish::Test -e1");
+    if ($error) {
+        print STDERR "Build succeeded, but 'use Clownfish::Test' failed.\n";
+        my $makefile = do { local(@ARGV, $/) = 'Makefile'; <> };
+        print STDERR "Contents of Makefile:\n$makefile";
+        die;
+    }
 }
 
 sub ACTION_clownfish {
@@ -311,6 +324,9 @@ sub ACTION_clean {
 sub ACTION_dist {
     my $self = shift;
 
+    die("Module::Build 0.40_11 is required for ./Build dist")
+        if $Module::Build::VERSION < 0.40_11;
+
     # Create POD.
     $self->depends_on('clownfish');
     rmtree("autogen");
